@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2009-2012, Peter A. Bigot
+# Copyright 2009-2013, Peter A. Bigot
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain a
@@ -279,9 +279,9 @@ class AttributeUse (pyxb.cscRoot):
 
     def _description (self, name_only=False, user_documentation=True):
         if name_only:
-            return str(self.__name)
+            return unicode(self.__name)
         assert issubclass(self.__dataType, basis._TypeBinding_mixin)
-        desc = [ str(self.__id), ': ', str(self.__name), ' (', self.__dataType._description(name_only=True, user_documentation=False), '), ' ]
+        desc = [ unicode(self.__id), ': ', unicode(self.__name), ' (', self.__dataType._description(name_only=True, user_documentation=False), '), ' ]
         if self.__required:
             desc.append('required')
         elif self.__prohibited:
@@ -1036,7 +1036,7 @@ class ElementDeclaration (object):
         if ctd_instance._isNil():
             raise pyxb.ContentInNilInstanceError(ctd_instance, value)
         if not self.isPlural():
-            raise pyxb.StructuralBadDocumentError('Cannot append to element with non-plural multiplicity')
+            raise pyxb.NonPluralAppendError(ctd_instance, self, value)
         values = self.value(ctd_instance)
         if ctd_instance._validationConfig.forBinding:
             value = self.__elementBinding.compatibleValue(value)
@@ -1087,12 +1087,12 @@ class ElementDeclaration (object):
 
     def _description (self, name_only=False, user_documentation=True):
         if name_only:
-            return str(self.__name)
-        desc = [ str(self.__id), ': ']
+            return unicode(self.__name)
+        desc = [ unicode(self.__id), ': ']
         if self.isPlural():
             desc.append('MULTIPLE ')
         desc.append(self.elementBinding()._description(user_documentation=user_documentation))
-        return ''.join(desc)
+        return u''.join(desc)
 
     def _matches (self, value, element_decl):
         accept = False
