@@ -15,7 +15,7 @@ for f in sys.argv[1:]:
         instance = sos.CreateFromDocument(xmls)
         #print xmls
         print instance.toxml("utf-8")
-    except Exception, e:
+    except Exception as e:
         print '%s failed: %s' % (f, e)
         traceback.print_exception(*sys.exc_info())
     
