@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/soap11.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:124ab58ff634848548cf6d9d1320f856ff23519e
-# Generated 2012-12-17 13:09:26.082347 by PyXB version 1.2.1
+# Generated 2013-04-17 03:14:11.863436 by PyXB version 1.2.2
 # Namespace http://schemas.xmlsoap.org/soap/envelope/
 
 import pyxb
@@ -13,15 +13,20 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:4636d720-487d-11e2-84d8-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:c918d284-a736-11e2-a226-c8600024e903')
+
+# Version of PyXB used to generate the bindings
+_PyXBVersion = '1.2.2'
+# Generated bindings are not compatible across PyXB versions
+if pyxb.__version__ != _PyXBVersion:
+    raise pyxb.PyXBVersionError(_PyXBVersion)
 
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
 
+# NOTE: All namespace declarations are reserved within the binding
 Namespace = pyxb.namespace.NamespaceForURI(u'http://schemas.xmlsoap.org/soap/envelope/', create_if_missing=True)
 Namespace.configureCategories(['typeBinding', 'elementBinding'])
-ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
-ModuleRecord._setModule(sys.modules[__name__])
 
 def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a
@@ -65,7 +70,7 @@ class STD_ANON (pyxb.binding.datatypes.boolean):
     """An atomic simple type."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 76, 5)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 76, 5)
     _Documentation = None
 STD_ANON._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON._CF_pattern.addPattern(pattern=u'0|1')
@@ -80,7 +85,7 @@ class encodingStyle (pyxb.binding.basis.STD_list):
 	  """
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'encodingStyle')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 84, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 84, 2)
     _Documentation = u"\n\t    'encodingStyle' indicates any canonicalization conventions followed in the contents of the containing element.  For example, the value 'http://schemas.xmlsoap.org/soap/encoding/' indicates the pattern described in SOAP specification\n\t  "
 
     _ItemType = pyxb.binding.datatypes.anyURI
@@ -94,32 +99,33 @@ class Envelope_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Envelope')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 42, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 42, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://schemas.xmlsoap.org/soap/envelope/}Header uses Python identifier Header
-    __Header = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Header'), 'Header', '__httpschemas_xmlsoap_orgsoapenvelope_Envelope__httpschemas_xmlsoap_orgsoapenvelopeHeader', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2), )
+    __Header = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Header'), 'Header', '__httpschemas_xmlsoap_orgsoapenvelope_Envelope__httpschemas_xmlsoap_orgsoapenvelopeHeader', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2), )
 
     
     Header = property(__Header.value, __Header.set, None, None)
 
     
     # Element {http://schemas.xmlsoap.org/soap/envelope/}Body uses Python identifier Body
-    __Body = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Body'), 'Body', '__httpschemas_xmlsoap_orgsoapenvelope_Envelope__httpschemas_xmlsoap_orgsoapenvelopeBody', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2), )
+    __Body = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Body'), 'Body', '__httpschemas_xmlsoap_orgsoapenvelope_Envelope__httpschemas_xmlsoap_orgsoapenvelopeBody', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2), )
 
     
     Body = property(__Body.value, __Body.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/'))
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         __Header.name() : __Header,
         __Body.name() : __Body
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'Envelope', Envelope_)
 
 
@@ -130,17 +136,18 @@ class Header_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Header')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 52, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 52, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/'))
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'Header', Header_)
 
 
@@ -151,17 +158,18 @@ class Body_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Body')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 60, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 60, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'Body', Body_)
 
 
@@ -174,46 +182,47 @@ class Fault_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'Fault')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 99, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 99, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element faultcode uses Python identifier faultcode
-    __faultcode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultcode'), 'faultcode', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultcode', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6), )
+    __faultcode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultcode'), 'faultcode', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultcode', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6), )
 
     
     faultcode = property(__faultcode.value, __faultcode.set, None, None)
 
     
     # Element faultstring uses Python identifier faultstring
-    __faultstring = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultstring'), 'faultstring', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultstring', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6), )
+    __faultstring = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultstring'), 'faultstring', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultstring', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6), )
 
     
     faultstring = property(__faultstring.value, __faultstring.set, None, None)
 
     
     # Element faultactor uses Python identifier faultactor
-    __faultactor = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultactor'), 'faultactor', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultactor', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6), )
+    __faultactor = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'faultactor'), 'faultactor', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__faultactor', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6), )
 
     
     faultactor = property(__faultactor.value, __faultactor.set, None, None)
 
     
     # Element detail uses Python identifier detail
-    __detail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'detail'), 'detail', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__detail', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6), )
+    __detail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(None, u'detail'), 'detail', '__httpschemas_xmlsoap_orgsoapenvelope_Fault__detail', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6), )
 
     
     detail = property(__detail.value, __detail.set, None, None)
 
-
-    _ElementMap = {
+    _ElementMap.update({
         __faultcode.name() : __faultcode,
         __faultstring.name() : __faultstring,
         __faultactor.name() : __faultactor,
         __detail.name() : __detail
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'Fault', Fault_)
 
 
@@ -224,61 +233,62 @@ class detail (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'detail')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 113, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 113, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'detail', detail)
 
 
-Envelope = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Envelope'), Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 41, 2))
+Envelope = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Envelope'), Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 41, 2))
 Namespace.addCategoryObject('elementBinding', Envelope.name().localName(), Envelope)
 
-Header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2))
+Header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2))
 Namespace.addCategoryObject('elementBinding', Header.name().localName(), Header)
 
-Body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2))
+Body = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2))
 Namespace.addCategoryObject('elementBinding', Body.name().localName(), Body)
 
-Fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Fault'), Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 98, 2))
+Fault = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Fault'), Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 98, 2))
 Namespace.addCategoryObject('elementBinding', Fault.name().localName(), Fault)
 
 
 
-Envelope_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_, scope=Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2)))
+Envelope_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Header'), Header_, scope=Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 51, 2)))
 
-Envelope_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_, scope=Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2)))
+Envelope_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Body'), Body_, scope=Envelope_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 59, 2)))
 
 def _BuildAutomaton ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton
     del _BuildAutomaton
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 44, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 44, 6))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 46, 6))
+    cc_1 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 46, 6))
     counters.add(cc_1)
     states = []
     final_update = None
-    symbol = pyxb.binding.content.ElementUse(Envelope_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Header')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 44, 6))
+    symbol = pyxb.binding.content.ElementUse(Envelope_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Header')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 44, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(Envelope_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Body')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 45, 6))
+    symbol = pyxb.binding.content.ElementUse(Envelope_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Body')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 45, 6))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 46, 6))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 46, 6))
     st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     transitions = []
@@ -302,18 +312,18 @@ Envelope_._Automaton = _BuildAutomaton()
 
 
 def _BuildAutomaton_ ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_
     del _BuildAutomaton_
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 54, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 54, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 54, 6))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://schemas.xmlsoap.org/soap/envelope/')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 54, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -327,18 +337,18 @@ Header_._Automaton = _BuildAutomaton_()
 
 
 def _BuildAutomaton_2 ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_2
     del _BuildAutomaton_2
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 62, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 62, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 62, 6))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 62, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -351,42 +361,42 @@ Body_._Automaton = _BuildAutomaton_2()
 
 
 
-Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultcode'), pyxb.binding.datatypes.QName, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6)))
+Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultcode'), pyxb.binding.datatypes.QName, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6)))
 
-Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultstring'), pyxb.binding.datatypes.string, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6)))
+Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultstring'), pyxb.binding.datatypes.string, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6)))
 
-Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultactor'), pyxb.binding.datatypes.anyURI, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6)))
+Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'faultactor'), pyxb.binding.datatypes.anyURI, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6)))
 
-Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'detail'), detail, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6)))
+Fault_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(None, u'detail'), detail, scope=Fault_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6)))
 
 def _BuildAutomaton_3 ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_3
     del _BuildAutomaton_3
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6))
+    cc_1 = fac.CounterCondition(min=0L, max=1, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6))
     counters.add(cc_1)
     states = []
     final_update = None
-    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultcode')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6))
+    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultcode')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 106, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultstring')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6))
+    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultstring')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 107, 6))
     st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultactor')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6))
+    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'faultactor')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 108, 6))
     st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'detail')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6))
+    symbol = pyxb.binding.content.ElementUse(Fault_._UseForTag(pyxb.namespace.ExpandedName(None, u'detail')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 109, 6))
     st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     transitions = []
@@ -416,18 +426,18 @@ Fault_._Automaton = _BuildAutomaton_3()
 
 
 def _BuildAutomaton_4 ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_4
     del _BuildAutomaton_4
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 115, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 115, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/soap11.xsd', 115, 6))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/soap11.xsd', 115, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
