@@ -1,7 +1,7 @@
 # ./pyxb/bundles/wssplat/raw/wsp200607.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:f7a1b3ccf248600ac00f0ba01aeba7fdd42b4412
-# Generated 2012-12-17 13:09:28.646710 by PyXB version 1.2.1
+# Generated 2013-04-17 03:14:14.469191 by PyXB version 1.2.2
 # Namespace http://www.w3.org/2006/07/ws-policy
 
 import pyxb
@@ -13,15 +13,23 @@ import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:47bd3dd2-487d-11e2-90d0-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:caa56838-a736-11e2-ba87-c8600024e903')
+
+# Version of PyXB used to generate the bindings
+_PyXBVersion = '1.2.2'
+# Generated bindings are not compatible across PyXB versions
+if pyxb.__version__ != _PyXBVersion:
+    raise pyxb.PyXBVersionError(_PyXBVersion)
 
 # Import bindings for namespaces imported into schema
+import pyxb.bundles.wssplat.wsu
 import pyxb.binding.datatypes
 
+# NOTE: All namespace declarations are reserved within the binding
 Namespace = pyxb.namespace.NamespaceForURI(u'http://www.w3.org/2006/07/ws-policy', create_if_missing=True)
 Namespace.configureCategories(['typeBinding', 'elementBinding'])
-ModuleRecord = Namespace.lookupModuleRecordByUID(_GenerationUID, create_if_missing=True)
-ModuleRecord._setModule(sys.modules[__name__])
+_Namespace_wsu = pyxb.bundles.wssplat.wsu.Namespace
+_Namespace_wsu.configureCategories(['typeBinding', 'elementBinding'])
 
 def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a
@@ -66,7 +74,7 @@ class STD_ANON (pyxb.binding.basis.STD_list):
     """Simple type that is a list of pyxb.binding.datatypes.anyURI."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 74, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 74, 4)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.anyURI
@@ -79,47 +87,48 @@ class OperatorContentType (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'OperatorContentType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 46, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 46, 2)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicy', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2), )
+    __Policy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicy', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2), )
 
     
     Policy = property(__Policy.value, __Policy.set, None, None)
 
     
     # Element {http://www.w3.org/2006/07/ws-policy}All uses Python identifier All
-    __All = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'All'), 'All', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyAll', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2), )
+    __All = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'All'), 'All', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyAll', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2), )
 
     
     All = property(__All.value, __All.set, None, None)
 
     
     # Element {http://www.w3.org/2006/07/ws-policy}ExactlyOne uses Python identifier ExactlyOne
-    __ExactlyOne = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), 'ExactlyOne', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyExactlyOne', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2), )
+    __ExactlyOne = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), 'ExactlyOne', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyExactlyOne', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2), )
 
     
     ExactlyOne = property(__ExactlyOne.value, __ExactlyOne.set, None, None)
 
     
     # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicyReference', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2), )
+    __PolicyReference = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_OperatorContentType_httpwww_w3_org200607ws_policyPolicyReference', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2), )
 
     
     PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
 
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         __Policy.name() : __Policy,
         __All.name() : __All,
         __ExactlyOne.name() : __ExactlyOne,
         __PolicyReference.name() : __PolicyReference
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 Namespace.addCategoryObject('typeBinding', u'OperatorContentType', OperatorContentType)
 
 
@@ -130,42 +139,43 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 60, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 60, 4)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Attribute URI uses Python identifier URI
     __URI = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'URI'), 'URI', '__httpwww_w3_org200607ws_policy_CTD_ANON_URI', pyxb.binding.datatypes.anyURI, required=True)
-    __URI._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 61, 6)
-    __URI._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 61, 6)
+    __URI._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 61, 6)
+    __URI._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 61, 6)
     
     URI = property(__URI.value, __URI.set, None, None)
 
     
     # Attribute Digest uses Python identifier Digest
     __Digest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Digest'), 'Digest', '__httpwww_w3_org200607ws_policy_CTD_ANON_Digest', pyxb.binding.datatypes.base64Binary)
-    __Digest._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 63, 6)
-    __Digest._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 63, 6)
+    __Digest._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 63, 6)
+    __Digest._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 63, 6)
     
     Digest = property(__Digest.value, __Digest.set, None, None)
 
     
     # Attribute DigestAlgorithm uses Python identifier DigestAlgorithm
     __DigestAlgorithm = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'DigestAlgorithm'), 'DigestAlgorithm', '__httpwww_w3_org200607ws_policy_CTD_ANON_DigestAlgorithm', pyxb.binding.datatypes.anyURI, unicode_default=u'http://www.w3.org/2006/07/policy/Sha1Exc')
-    __DigestAlgorithm._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 64, 6)
-    __DigestAlgorithm._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 64, 6)
+    __DigestAlgorithm._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 64, 6)
+    __DigestAlgorithm._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 64, 6)
     
     DigestAlgorithm = property(__DigestAlgorithm.value, __DigestAlgorithm.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
-
-    _ElementMap = {
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         __URI.name() : __URI,
         __Digest.name() : __Digest,
         __DigestAlgorithm.name() : __DigestAlgorithm
-    }
+    })
 
 
 
@@ -176,40 +186,41 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 80, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 80, 4)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://www.w3.org/2006/07/ws-policy}Policy uses Python identifier Policy
-    __Policy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicy', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2), )
+    __Policy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'Policy'), 'Policy', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicy', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2), )
 
     
     Policy = property(__Policy.value, __Policy.set, None, None)
 
     
     # Element {http://www.w3.org/2006/07/ws-policy}PolicyReference uses Python identifier PolicyReference
-    __PolicyReference = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicyReference', True, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2), )
+    __PolicyReference = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), 'PolicyReference', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyPolicyReference', True, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2), )
 
     
     PolicyReference = property(__PolicyReference.value, __PolicyReference.set, None, None)
 
     
     # Element {http://www.w3.org/2006/07/ws-policy}AppliesTo uses Python identifier AppliesTo
-    __AppliesTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyAppliesTo', False, pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2), )
+    __AppliesTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), 'AppliesTo', '__httpwww_w3_org200607ws_policy_CTD_ANON__httpwww_w3_org200607ws_policyAppliesTo', False, pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2), )
 
     
     AppliesTo = property(__AppliesTo.value, __AppliesTo.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         __Policy.name() : __Policy,
         __PolicyReference.name() : __PolicyReference,
         __AppliesTo.name() : __AppliesTo
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 
 
 
@@ -220,17 +231,18 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 99, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 99, 4)
+    _ElementMap = {}
+    _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
-
-    _ElementMap = {
+    _ElementMap.update({
         
-    }
-    _AttributeMap = {
+    })
+    _AttributeMap.update({
         
-    }
+    })
 
 
 
@@ -241,7 +253,9 @@ class CTD_ANON_3 (OperatorContentType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 31, 4)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 31, 4)
+    _ElementMap = OperatorContentType._ElementMap.copy()
+    _AttributeMap = OperatorContentType._AttributeMap.copy()
     # Base type is OperatorContentType
     
     # Element Policy ({http://www.w3.org/2006/07/ws-policy}Policy) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
@@ -253,28 +267,25 @@ class CTD_ANON_3 (OperatorContentType):
     # Element PolicyReference ({http://www.w3.org/2006/07/ws-policy}PolicyReference) inherited from {http://www.w3.org/2006/07/ws-policy}OperatorContentType
     
     # Attribute {http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd}Id uses Python identifier Id
-    __Id = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(pyxb.namespace.NamespaceForURI(u'http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd'), u'Id'), 'Id', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpdocs_oasis_open_orgwss200401oasis_200401_wss_wssecurity_utility_1_0_xsdId', pyxb.binding.datatypes.ID)
-    __Id._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsu.xsd', 28, 1)
-    __Id._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 36, 10)
+    __Id = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(_Namespace_wsu, u'Id'), 'Id', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_httpdocs_oasis_open_orgwss200401oasis_200401_wss_wssecurity_utility_1_0_xsdId', pyxb.binding.datatypes.ID)
+    __Id._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsu.xsd', 28, 1)
+    __Id._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 36, 10)
     
     Id = property(__Id.value, __Id.set, None, u'\nThis global attribute supports annotating arbitrary elements with an ID.\n          ')
 
     
     # Attribute Name uses Python identifier Name
     __Name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'Name'), 'Name', '__httpwww_w3_org200607ws_policy_CTD_ANON_3_Name', pyxb.binding.datatypes.anyURI)
-    __Name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 35, 10)
-    __Name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 35, 10)
+    __Name._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 35, 10)
+    __Name._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 35, 10)
     
     Name = property(__Name.value, __Name.set, None, None)
 
     _AttributeWildcard = pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any)
     _HasWildcardElement = True
-
-    _ElementMap = OperatorContentType._ElementMap.copy()
     _ElementMap.update({
         
     })
-    _AttributeMap = OperatorContentType._AttributeMap.copy()
     _AttributeMap.update({
         __Id.name() : __Id,
         __Name.name() : __Name
@@ -282,67 +293,67 @@ class CTD_ANON_3 (OperatorContentType):
 
 
 
-All = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2))
+All = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2))
 Namespace.addCategoryObject('elementBinding', All.name().localName(), All)
 
-ExactlyOne = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2))
+ExactlyOne = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2))
 Namespace.addCategoryObject('elementBinding', ExactlyOne.name().localName(), ExactlyOne)
 
-PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2))
+PolicyReference = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2))
 Namespace.addCategoryObject('elementBinding', PolicyReference.name().localName(), PolicyReference)
 
-PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 79, 2))
+PolicyAttachment = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyAttachment'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 79, 2))
 Namespace.addCategoryObject('elementBinding', PolicyAttachment.name().localName(), PolicyAttachment)
 
-AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2))
+AppliesTo = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2))
 Namespace.addCategoryObject('elementBinding', AppliesTo.name().localName(), AppliesTo)
 
-Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2))
+Policy = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2))
 Namespace.addCategoryObject('elementBinding', Policy.name().localName(), Policy)
 
 
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2)))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'All'), OperatorContentType, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 43, 2)))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2)))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne'), OperatorContentType, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 44, 2)))
 
-OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2)))
+OperatorContentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=OperatorContentType, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2)))
 
 def _BuildAutomaton ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton
     del _BuildAutomaton
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 48, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 48, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 49, 8))
+    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 49, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 50, 8))
+    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 50, 8))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 51, 8))
+    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 51, 8))
     st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 53, 8))
+    symbol = pyxb.binding.content.ElementUse(OperatorContentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 53, 8))
     st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 54, 8))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 54, 8))
     st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_4)
     transitions = []
@@ -411,37 +422,37 @@ OperatorContentType._Automaton = _BuildAutomaton()
 
 
 
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)))
+CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'Policy'), CTD_ANON_3, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 30, 2)))
 
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2)))
+CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference'), CTD_ANON, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 59, 2)))
 
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2)))
+CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo'), CTD_ANON_2, scope=CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 98, 2)))
 
 def _BuildAutomaton_ ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_
     del _BuildAutomaton_
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 91, 8))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 91, 8))
     counters.add(cc_0)
     states = []
     final_update = None
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 83, 8))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'AppliesTo')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 83, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 85, 10))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 85, 10))
     st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 86, 10))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 86, 10))
     st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 91, 8))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 91, 8))
     st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     transitions = []
@@ -477,7 +488,7 @@ CTD_ANON_._Automaton = _BuildAutomaton_()
 
 
 def _BuildAutomaton_2 ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_2
     del _BuildAutomaton_2
     import pyxb.utils.fac as fac
@@ -485,7 +496,7 @@ def _BuildAutomaton_2 ():
     counters = set()
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 101, 8))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 101, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -499,38 +510,38 @@ CTD_ANON_2._Automaton = _BuildAutomaton_2()
 
 
 def _BuildAutomaton_3 ():
-    # Remove this helper function from the namespace after it's invoked
+    # Remove this helper function from the namespace after it is invoked
     global _BuildAutomaton_3
     del _BuildAutomaton_3
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 48, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 48, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 49, 8))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'Policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 49, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 50, 8))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'All')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 50, 8))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 51, 8))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'ExactlyOne')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 51, 8))
     st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_2)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 53, 8))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, u'PolicyReference')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 53, 8))
     st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_3)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.gTSiuHf/PyXB-1.2.1/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 54, 8))
+    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=(pyxb.binding.content.Wildcard.NC_not, u'http://www.w3.org/2006/07/ws-policy')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsp200607.xsd', 54, 8))
     st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_4)
     transitions = []
