@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 import pyxb
 import unittest
 import pyxb.binding.datatypes as xsd
