@@ -62,17 +62,23 @@ def ToDOM (instance):
 import unittest
 
 class TestExternal (unittest.TestCase):
+    def setUp (self):
+        self.__basis_log = logging.getLogger('pyxb.binding.basis')
+        self.__basis_loglevel = self.__basis_log.level
+
+    def tearDown (self):
+        self.__basis_log.level = self.__basis_loglevel
 
     def testSharedTypes (self):
         self.assertEqual(word.typeDefinition()._ElementMap['from'].elementBinding().typeDefinition(), st.english)
         self.assertEqual(word.typeDefinition()._ElementMap['to'].elementBinding().typeDefinition(), st.welsh)
         one = st.english('one')
-        self.assertRaises(BadTypeValueError, st.english, 'five')
+        self.assertRaises(SimpleTypeValueError, st.english, 'five')
         # Element constructor without content is error
-        self.assertRaises(BadTypeValueError, english)
+        self.assertRaises(SimpleTypeValueError, english)
         self.assertEqual('one', english('one'))
         # Element constructor with out-of-range content is error
-        self.assertRaises(BadTypeValueError, english, 'five')
+        self.assertRaises(SimpleTypeValueError, english, 'five')
 
         xml = '<ns1:english xmlns:ns1="URN:test-external">one</ns1:english>'
         instance = st.CreateFromDocument(xml)
@@ -88,7 +94,7 @@ class TestExternal (unittest.TestCase):
         
     def testBadWords (self):
         xml = '<ns1:word xmlns:ns1="URN:test-external"><from>five</from><to>pump</to></ns1:word>'
-        self.assertRaises(BadTypeValueError, CreateFromDocument, xml)
+        self.assertRaises(SimpleTypeValueError, CreateFromDocument, xml)
 
     def testComplexShared (self):
         xml = '<ns1:lwords language="english" newlanguage="welsh" xmlns:ns1="URN:test-external">un</ns1:lwords>'
@@ -112,7 +118,9 @@ class TestExternal (unittest.TestCase):
         instance = st.personName.Factory(_dom_node=dom.documentElement)
         xml = '<personName><surname>Smith</surname><generation>Jr.</generation></personName>'
         dom = pyxb.utils.domutils.StringToDOM(xml)
-        self.assertRaises(ExtraContentError, st.personName.Factory, _dom_node=dom.documentElement)
+        self.__basis_log.setLevel(logging.ERROR)
+        self.assertRaises(UnrecognizedContentError, st.personName.Factory, _dom_node=dom.documentElement)
+        self.__basis_log.level = self.__basis_loglevel
         xml = xml.replace('personName', 'extendedName')
         dom = pyxb.utils.domutils.StringToDOM(xml)
         instance = st.extendedName.Factory(_dom_node=dom.documentElement)
