@@ -1,8 +1,13 @@
+# -*- coding: utf-8 -*-
+import logging
+if __name__ == '__main__':
+    logging.basicConfig()
+_log = logging.getLogger(__name__)
 import pyxb.binding.generate
 import pyxb.utils.domutils
 
 import os.path
-schema_path = '%s/../schemas/test-include-ddq.xsd' % (os.path.dirname(__file__),)
+schema_path = os.path.abspath(os.path.join(os.path.dirname(__file__), '../schemas/test-include-ddq.xsd'))
 code = pyxb.binding.generate.GeneratePython(schema_location=schema_path)
 #file('code.py', 'w').write(code)
 rv = compile(code, 'test', 'exec')
