@@ -22,6 +22,10 @@ from pyxb.exceptions_ import *
 
 import unittest
 
+def setFull (instance, value):
+    instance.full = value
+    return instance
+
 class TestXSIType (unittest.TestCase):
 
     def testFull (self):
@@ -121,11 +125,11 @@ class TestXSIType (unittest.TestCase):
 
     def testNilOptionalSpaceContent (self):
         xml = '<optional xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"> </optional>'
-        self.assertRaises(pyxb.ExtraContentError, CreateFromDocument, xml)
+        self.assertRaises(pyxb.ContentInNilInstanceError, CreateFromDocument, xml)
 
     def testNilComplexSpaceContent (self):
         xml = '<complex xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:nil="true"> </complex>'
-        self.assertRaises(pyxb.ExtraContentError, CreateFromDocument, xml)
+        self.assertRaises(pyxb.ContentInNilInstanceError, CreateFromDocument, xml)
 
     def testComplexInternal (self):
         xml = '<complex><full>full content</full><optional>optional content</optional></complex>'
@@ -178,6 +182,36 @@ class TestXSIType (unittest.TestCase):
             self.assertEqual(instance.toDOM().documentElement.toxml("utf-8"), canonical)
             instance.validateBinding()
 
+    def testConstructorNil (self):
+        o = optional()
+        self.assertFalse(o._isNil())
+        o = optional(_nil=True)
+        self.assertTrue(o._isNil())
+        c = complex()
+        self.assertFalse(c._isNil())
+        c = complex(_nil=True)
+        self.assertTrue(c._isNil())
+        s = simple()
+        self.assertFalse(s._isNil())
+        s = simple(_nil=True)
+        self.assertTrue(s._isNil())
+
+    def testNilSetAndAppend (self):
+        s = simple(_nil=True)
+        self.assertRaises(pyxb.ContentInNilInstanceError, s.append, 'one')
+        c = complex(_nil=True)
+        self.assertRaises(pyxb.ContentInNilInstanceError, c.append, 'one')
+        full = c._UseForTag('full')
+        self.assertRaises(pyxb.ContentInNilInstanceError, setFull, c, 'yes')
+        self.assertRaises(pyxb.ContentInNilInstanceError, full.append, c, 'yes')
+        self.assertRaises(pyxb.ContentInNilInstanceError, full.setOrAppend, c, 'yes')
+        multi = c._UseForTag('multi')
+        self.assertRaises(pyxb.ContentInNilInstanceError, multi.append, c, 'one')
+        self.assertRaises(pyxb.ContentInNilInstanceError, multi.setOrAppend, c, 'one')
+        # Nothing we can do about assignments that bypass the validation hooks.
+        # Customizing list would probably destroy performance.
+        c.multi.append('one')
+
 if __name__ == '__main__':
     unittest.main()
     
