@@ -58,38 +58,46 @@ eval(rv)
 from pyxb.exceptions_ import *
 
 import unittest
+import collections
+
+# Pretend whoever created the schema was helpful and had normalized it
+metadatadoc_type = MetadataDocument.typeDefinition()
+timespan_element = metadatadoc_type._ElementMap['timespan'].elementBinding()
+timespan_type = timespan_element.typeDefinition()
+field_element = timespan_type._ElementMap['field'].elementBinding()
+field_type = field_element.typeDefinition()
+value_element = field_type._ElementMap['value'].elementBinding()
+value_type = value_element.typeDefinition()
+
+v_bind = pyxb.BIND('foo', lang='ENG')
 
 class TestTrac_0071 (unittest.TestCase):
-    def test (self):
-        newdoc = MetadataDocument()
-        metadatadoc_type = MetadataDocument.typeDefinition()
-        timespan_element = metadatadoc_type._ElementMap['timespan'].elementBinding()
-        timespan_type = timespan_element.typeDefinition()
-        field_element = timespan_type._ElementMap['field'].elementBinding()
-        field_type = field_element.typeDefinition()
-        value_element = field_type._ElementMap['value'].elementBinding()
-        value_type = value_element.typeDefinition()
-        newdoc.template = 'anewtemplate'
-
+    def testFieldConstructor (self):
         field = field_type('title', pyxb.BIND('foo', lang='ENG'), _element=field_element)
-        self.assertTrue(isinstance(field.value_, list))
+        self.assertTrue(isinstance(field.value_, collections.MutableSequence))
         self.assertEqual(1, len(field.value_))
         self.assertTrue(isinstance(field.value_[0], value_type))
         field.validateBinding()
         self.assertEqual('<field><name>title</name><value lang="ENG">foo</value></field>', field.toxml("utf-8", root_only=True))
 
+    def testFieldElementAppend (self):
+        newdoc = MetadataDocument()
+        newdoc.template = 'anewtemplate'
+
         field = field_type(name='title', _element=field_element)
         field.value_.append(pyxb.BIND('foo', lang='ENG'))
-        self.assertTrue(isinstance(field.value_, list))
+        self.assertTrue(isinstance(field.value_, collections.MutableSequence))
         self.assertEqual(1, len(field.value_))
-        self.assertTrue(isinstance(field.value_[0], pyxb.BIND))
+        self.assertTrue(isinstance(field.value_[0], value_type))
         field.validateBinding()
-        self.assertTrue(isinstance(field.value_[0], pyxb.BIND))
+        self.assertTrue(isinstance(field.value_[0], value_type))
         self.assertEqual('<field><name>title</name><value lang="ENG">foo</value></field>', field.toxml("utf-8", root_only=True))
 
-        '''
+    MetaExpected = '<ns1:MetadataDocument xmlns:ns1="urn:trac-0071"><template>anewtemplate</template><timespan end="+INF" start="-INF"><field><name>title</name><value lang="ENG">foo</value></field></timespan></ns1:MetadataDocument>'
 
-        NOT YET FINISHED
+    def testMetaConstructor (self):
+        newdoc = MetadataDocument()
+        newdoc.template = 'anewtemplate'
 
         newdoc.timespan.append(pyxb.BIND( # Single timespan
                 pyxb.BIND( # First field instance
@@ -97,37 +105,59 @@ class TestTrac_0071 (unittest.TestCase):
                     pyxb.BIND('foo', lang='ENG')
                     ),
                 start='-INF', end='+INF'))
+        timespan = newdoc.timespan[0]
+        self.assertTrue(isinstance(timespan, timespan_type))
         newdoc.validateBinding()
         timespan = newdoc.timespan[0]
-        #self.assertTrue(isinstance(timespan, timespan_type))
-        print newdoc.toxml("utf-8")
-        newdoc.timespan[:] = []
-        
-        newdoc.timespan.append(pyxb.BIND( # Single timespan
-                pyxb.BIND( # First field instance
-                    name='title',
-                    value=pyxb.BIND('foo', lang='ENG')
-                    ),
-                start='-INF', end='+INF'))
-        newdoc.validateBinding()
-        timespan = newdoc.timespan[0]
-        #self.assertTrue(isinstance(timespan, timespan_type))
-        print newdoc.toxml("utf-8")
+        self.assertTrue(isinstance(timespan, timespan_type))
+        self.assertEqual(self.MetaExpected, newdoc.toxml("utf-8", root_only=True))
         newdoc.timespan[:] = []
 
-        newdoc.timespan.append(pyxb.BIND( # Single timespan
-                pyxb.BIND( # First field instance
-                    name='title',
-                    value_=pyxb.BIND('foo', lang='ENG')
-                    ),
-                start='-INF', end='+INF'))
-        newdoc.validateBinding()
-        timespan = newdoc.timespan[0]
-        #self.assertTrue(isinstance(timespan, timespan_type))
-        print newdoc.toxml("utf-8")
-        newdoc.timespan[:] = []
+    def testMetaBadFieldName (self):
+        newdoc = MetadataDocument()
+        newdoc.template = 'anewtemplate'
 
-        '''
+        v_bind = pyxb.BIND('foo', lang='ENG')
+
+        # This binding is wrong: the field name is "value_" not "value"
+        f_bind = pyxb.BIND(name='title', value=v_bind)
+        ts_bind = pyxb.BIND(f_bind, start='-INF', end='+INF')
+        if sys.version_info[:2] < (2, 7):
+            self.assertRaises(pyxb.UnrecognizedContentError, newdoc.timespan.append, ts_bind)
+            return
+        with self.assertRaises(pyxb.UnrecognizedContentError) as cm:
+            newdoc.timespan.append(ts_bind)
+        self.assertEqual(f_bind, cm.exception.value)
+
+    def testMetaBadPlurality (self):
+        newdoc = MetadataDocument()
+        newdoc.template = 'anewtemplate'
+
+        # This binding is wrong: the field "value_" is plural and the
+        # value for the keyword must be iterable.
+        f_bind = pyxb.BIND(name='title', value_=v_bind)
+        ts_bind = pyxb.BIND(f_bind, start='-INF', end='+INF')
+        if sys.version_info[:2] < (2, 7):
+            self.assertRaises(pyxb.UnrecognizedContentError, newdoc.timespan.append, ts_bind)
+            return
+        with self.assertRaises(pyxb.UnrecognizedContentError) as cm:
+            newdoc.timespan.append(ts_bind)
+        self.assertEqual(f_bind, cm.exception.value)
+
+    def testMetaGoodBind (self):
+        newdoc = MetadataDocument()
+        newdoc.template = 'anewtemplate'
+
+        # This one should be OK
+        bind = pyxb.BIND( # First field instance
+                    name='title',
+                    value_=[pyxb.BIND('foo', lang='ENG')]
+                    )
+        newdoc.timespan.append(pyxb.BIND(bind, start='-INF', end='+INF'))
+        timespan = newdoc.timespan[0]
+        self.assertTrue(isinstance(timespan, timespan_type))
+        newdoc.validateBinding()
+        self.assertEqual(self.MetaExpected, newdoc.toxml("utf-8", root_only=True))
 
 if __name__ == '__main__':
     unittest.main()
