@@ -4,9 +4,20 @@ if __name__ == '__main__':
     logging.basicConfig()
 _log = logging.getLogger(__name__)
 import pyxb.binding.generate
+import sys
 import unittest
 
 class TestTrac0099a (unittest.TestCase):
+    def setUp (self):
+        # Hide the error about failure to check value constraint
+        self.__structures_log = logging.getLogger('pyxb.xmlschema.structures')
+        self.__structures_loglevel = self.__structures_log.level
+        self.__structures_log.setLevel(logging.CRITICAL)
+
+    def tearDown (self):
+        pyxb.RequireValidWhenParsing(True)
+        self.__structures_log.level = self.__structures_loglevel
+
     def testRefWithAttrs (self):
         xsd = '''<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">
   <xs:element name="uncs" type="xs:string"/>
@@ -36,7 +47,7 @@ class TestTrac0099a (unittest.TestCase):
         with self.assertRaises(pyxb.SchemaValidationError) as cm:
             code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
             print code
-        print cm.exception
+        self.assertEqual(u'Value constraint on element complex with non-simple content', str(cm.exception))
 
 if __name__ == '__main__':
     unittest.main()
