@@ -37,12 +37,7 @@ targetNamespace="urn:trac0112" version="1.0">
 </xs:schema>
 '''
 
-xmls = '''<?xml version="1.0" encoding="UTF-8"?>
-<Element xmlns="urn:trac0112">
-  <Inner>
-    <C>true</C>
-  </Inner>
-</Element>'''
+xmls = '''<?xml version="1.0" ?><Element xmlns="urn:trac0112"><Inner><C>true</C></Inner></Element>'''
 
 
 code = pyxb.binding.generate.GeneratePython(schema_text=xsd)
@@ -56,10 +51,15 @@ from pyxb.exceptions_ import *
 import unittest
 
 class TestTrac0112 (unittest.TestCase):
-    def testExample (self):
-        print "NOTE: THIS TEST ACTUALLY FAILS (we're validating that it does fail)"
-        self.assertRaises(pyxb.BindingValidationError, CreateFromDocument, xmls)
+    def setUp (self):
+        pyxb.utils.domutils.BindingDOMSupport.SetDefaultNamespace(Namespace.uri())
 
+    def tearDown (self):
+        pyxb.utils.domutils.BindingDOMSupport.SetDefaultNamespace(None)
+
+    def testExample (self):
+        instance = CreateFromDocument(xmls)
+        self.assertEqual(xmls, instance.toxml())
 
 if __name__ == '__main__':
     unittest.main()
