@@ -53,22 +53,22 @@ class TestTrac0122 (unittest.TestCase):
         instance = Element()
         self.assertEqual(None, instance.Required)
         self.assertEqual(None, instance.Optional)
-        self.assertEqual(None, self.getProhibited(instance))
+        self.assertRaises(pyxb.ProhibitedAttributeError, self.getProhibited, instance)
 
         self.setRequired(instance, 'one')
         self.setOptional(instance, 'two')
-        self.assertRaises(AttributeError, self.setProhibitedNaive, instance, 'three')
+        self.assertRaises(pyxb.ProhibitedAttributeError, self.setProhibitedNaive, instance, 'three')
         self.assertRaises(pyxb.ProhibitedAttributeError, self.setProhibited, instance, 'three')
         self.assertEqual('one', instance.Required)
         self.assertEqual('two', instance.Optional)
-        self.assertEqual(None, self.getProhibited(instance))
+        self.assertRaises(pyxb.ProhibitedAttributeError, self.getProhibited, instance)
 
         instance.Optional = None
         self.assertRaises(pyxb.MissingAttributeError, self.setRequired, instance, None)
-        self.setProhibited(instance, None)
+        self.assertRaises(pyxb.ProhibitedAttributeError, self.setProhibited, instance, None)
         self.assertEqual('one', instance.Required)
         self.assertEqual(None, instance.Optional)
-        self.assertEqual(None, self.getProhibited(instance))
+        self.assertRaises(pyxb.ProhibitedAttributeError, self.getProhibited, instance)
 
 
 if __name__ == '__main__':
