@@ -69,11 +69,8 @@ class TestTrac0131 (unittest.TestCase):
         instance = CreateFromDocument(xmls)
         self.assertEqual(instance.e, self.textu)
         pyxb._SetXMLStyle(pyxb.XMLStyle_minidom)
-        if sys.version_info[:2] == (2, 7):
-            self.assertRaises(self.ExpectedUnicodeErrors, CreateFromDocument, xmlu)
-        else:
-            instance = CreateFromDocument(xmlu)
-            self.assertEqual(instance.e, self.textu)
+        instance = CreateFromDocument(xmlu)
+        self.assertEqual(instance.e, self.textu)
         instance = CreateFromDocument(xmls)
         self.assertEqual(instance.e, self.textu)
         # saxdom can handle Unicode representation
@@ -93,7 +90,8 @@ class TestTrac0131 (unittest.TestCase):
         instance = CreateFromDocument(xmls)
         self.assertEqual(instance.e, self.textu)
         pyxb._SetXMLStyle(pyxb.XMLStyle_minidom)
-        self.assertRaises(self.ExpectedUnicodeErrors, CreateFromDocument, xmlu)
+        instance = CreateFromDocument(xmlu)
+        self.assertEqual(instance.e, self.textu)
         instance = CreateFromDocument(xmls)
         self.assertEqual(instance.e, self.textu)
         # saxdom can handle Unicode representation
