@@ -42,9 +42,10 @@ class TestTrac0163 (unittest.TestCase):
         try:
             instance = CreateFromDocument('<outer><inner>one</inner><inner>extra</inner></outer>')
             ran_test = False
-        except Exception, e:
-            self.assertTrue(isinstance(e, pyxb.ExtraContentError))
-            self.assertTrue(0 < str(e).find('starting with extra'))
+        except Exception as e:
+            self.assertTrue(isinstance(e, pyxb.UnrecognizedContentError))
+            self.assertTrue(isinstance(e.value, outer.typeDefinition()._UseForTag('inner').elementBinding().typeDefinition()))
+            self.assertEqual(e.value, 'extra')
         self.assertTrue(ran_test)
 
 if __name__ == '__main__':
